==> schlix-cms-v2.1.8-7.zip: schlix/system/themes/admindefault/header.template.php <==
<?php if (!defined('SCHLIX_VERSION')) die('No Access'); ?>
<?php define('ADMIN_THEME_URL_PATH', SCHLIX_SYSTEM_URL_PATH . '/themes/admindefault') ?>
<?php global $HTMLHeader; ?>
<meta charset="UTF-8">
<!-- Tell the browser to be responsive to screen width -->
<meta content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no" name="viewport">
<link rel="apple-touch-icon" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon.png" />
<link rel="apple-touch-icon" sizes="57x57" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-57x57.png" />
<link rel="apple-touch-icon" sizes="72x72" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-72x72.png" />
<link rel="apple-touch-icon" sizes="76x76" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-76x76.png" />
<link rel="apple-touch-icon" sizes="114x114" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-114x114.png" />
<link rel="apple-touch-icon" sizes="120x120" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-120x120.png" />
<link rel="apple-touch-icon" sizes="144x144" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-144x144.png" />
<link rel="apple-touch-icon" sizes="152x152" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-152x152.png" />
<link rel="apple-touch-icon" sizes="180x180" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-180x180.png" />
<link type="image/x-icon" rel="shortcut icon" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/favicon.ico" />
<!-- Fonts -->
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/open-sans/open-sans.css" />
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/source-sans-pro/source-sans-pro.css" />
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/font-awesome/font-awesome.min.css?v=5.2.0" />
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/glyphicons/glyphicons.css" />
<!-- CSS -->
<link type="text/css" rel="stylesheet" href="<?= ADMIN_THEME_URL_PATH ?>/css/bootstrap.min.css" />
<link type="text/css" rel="stylesheet" href="<?= ADMIN_THEME_URL_PATH ?>/css/schlix-admin-style.min.css" />
<link type="text/css" rel="stylesheet" href="<?= ADMIN_THEME_URL_PATH ?>/css/schlix-ui-dark.css" />
<link type="text/css" rel="stylesheet" href="<?= ADMIN_THEME_URL_PATH ?>/css/schlix-cms-dark.css" />
<!-- Chrome, Firefox OS and Opera -->
<meta name="theme-color" content="#222222">
<!-- Windows Phone -->
<meta name="msapplication-navbutton-color" content="#222222">
<!-- iOS Safari -->
<meta name="apple-mobile-web-app-status-bar-style" content="#222222">
<?= $HTMLHeader->JAVASCRIPT_JQUERY3(true); ?>
<script type="text/javascript" src="<?= SCHLIX_SYSTEM_URL_PATH ?>/js/bootstrap/3/bootstrap.min.js"></script>
<script type="text/javascript" src="<?= SCHLIX_SYSTEM_URL_PATH ?>/js/bootstrap/3/bootstrap-tokenfield.min.js"></script>
<script type="text/javascript" src="<?= SCHLIX_SYSTEM_URL_PATH ?>/js/bootstrap/3/bootstrap-iconpicker-fontawesome.js"></script>
<script type="text/javascript" src="<?= SCHLIX_SYSTEM_URL_PATH ?>/js/bootstrap/3/bootstrap-iconpicker.js"></script>
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/js/bootstrap/3/bootstrap-tokenfield.css" />
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/js/bootstrap/3/bootstrap-iconpicker.min.css" />
<script type="text/javascript" src="<?= ADMIN_THEME_URL_PATH ?>/js/theme.js"></script>
<!-- end theme -->
<?= $HTMLHeader->JAVASCRIPT_SCHLIX_UI(true); ?>
<?= $HTMLHeader->JAVASCRIPT_SCHLIX_CMS(true); ?>
<?= \SCHLIX\cmsPageOutput::HTMLHeader(); ?>

==> schlix-cms-v2.2.2-1.zip: schlix/system/themes/admindefault/header.template.php <==
<?php if (!defined('SCHLIX_VERSION')) die('No Access'); ?>
<?php define('ADMIN_THEME_URL_PATH', SCHLIX_SYSTEM_URL_PATH . '/themes/admindefault') ?>
<?php global $HTMLHeader; ?>
<meta charset="UTF-8">
<meta content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no" name="viewport">
<link rel="apple-touch-icon" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon.png" />
<link rel="apple-touch-icon" sizes="57x57" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-57x57.png" />
<link rel="apple-touch-icon" sizes="72x72" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-72x72.png" />
<link rel="apple-touch-icon" sizes="76x76" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-76x76.png" />
<link rel="apple-touch-icon" sizes="114x114" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-114x114.png" />
<link rel="apple-touch-icon" sizes="120x120" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-120x120.png" />
<link rel="apple-touch-icon" sizes="144x144" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-144x144.png" />
<link rel="apple-touch-icon" sizes="152x152" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-152x152.png" />
<link rel="apple-touch-icon" sizes="180x180" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/apple-touch-icon-180x180.png" />
<link type="image/x-icon" rel="shortcut icon" href="<?= ADMIN_THEME_URL_PATH; ?>/icons/favicon.ico" />
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/source-sans-pro/source-sans-pro.css" />
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/font-awesome/font-awesome.min.css" />
<link type="text/css" rel="stylesheet" href="<?= ADMIN_THEME_URL_PATH ?>/css/schlix-bootstrap.min.css?v=<?= SCHLIX_VERSION ?>" />
<link type="text/css" rel="stylesheet" href="<?= ADMIN_THEME_URL_PATH ?>/css/schlix-ui.css?v=<?= SCHLIX_VERSION ?>" />
<link type="text/css" rel="stylesheet" href="<?= ADMIN_THEME_URL_PATH ?>/css/schlix-cms.css?v=<?= SCHLIX_VERSION ?>" />
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/skins/bootstrap3/bootstrap-tokenfield.css" />
<link type="text/css" rel="stylesheet" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/skins/bootstrap3/bootstrap-iconpicker.min.css" />
<meta name="robots" content="noindex, nofollow">
<meta name="theme-color" content="#222222">
<meta name="msapplication-navbutton-color" content="#222222">
<meta name="apple-mobile-web-app-status-bar-style" content="#222222">

<?= \SCHLIX\cmsPageOutput::HTMLHeaderNonScripts(); ?>
